@@ -4,7 +4,8 @@
 // Description:
 // 与单个好友对话
 //
-// Author: Jally <jallyx@163.com>, (C) 2008
+// Author: cwll <cwll2009@126.com> ,(C) 2012.02
+//        Jally <jallyx@163.com>, (C) 2008
 //
 // Copyright: See COPYING file that comes with this distribution
 //
@@ -26,6 +27,8 @@ public:
         virtual void InsertPalData(PalInfo *pal);
         virtual void DelPalData(PalInfo *pal);
         virtual void ClearAllPalData();
+        virtual GSList *GetSelPal();
+        static void ShowDialogPeer(DialogPeer *dlgpr);
 private:
         void ReadUILayout();
         void WriteUILayout();
@@ -35,9 +38,16 @@ private:
 
         GtkWidget *CreateMenuBar();
         GtkWidget *CreateInfoArea();
+        GtkWidget *CreateFileArea();
+        GtkWidget *CreateFileReceiveArea();
+        GtkWidget *CreateFileToReceiveArea();
+        GtkWidget *CreateFileReceivedArea();
+        GtkWidget *CreateFileToReceiveTree(GtkTreeModel *model);
+        GtkTreeModel *CreateFileToReceiveModel();
+        GtkWidget *CreateFileReceivedTree(GtkTreeModel *model);
+        GtkTreeModel *CreateFileReceivedModel();
         GtkWidget *CreateFileMenu();
         GtkWidget *CreateToolMenu();
-
         void FillPalInfoToBuffer(GtkTextBuffer *buffer, PalInfo *pal);
 
 private:
@@ -52,11 +62,20 @@ private:
                                          guint info, guint time);
         static void AskSharedFiles(GroupInfo *grpinf);
         static void InsertPicture(DialogPeer *dlgpr);
-
         static void DialogPeerDestroy(DialogPeer *dlgpr);
+        static void ReceiveFile(DialogPeer *dlgpr);
+        static void ThreadRecvFile(FileInfo *file);
+        static void ShowInfoEnclosure(DialogPeer *dlgpr);
+        static bool UpdataEnclosureRcvUI(DialogPeer *dlgpr);
+        static void RemoveSelectedRcv(GtkWidget *widget);
+        static gint RcvTreePopup(GtkWidget *treeview,GdkEvent *event);
 //线程处理
 private:
         static void ThreadSendTextMsg(MsgPara *para);
+protected:
+        int64_t torcvsize;  //总计待接收大小(包括已接收)
+        int64_t rcvdsize;   //总计已接收大小
+        guint timerrcv;     //接收文件界面更新计时器ID
 };
 
 #endif
